@@ -4,7 +4,7 @@
 #    Project: Azimuthal integration
 #             https://github.com/silx-kit/pyFAI
 #
-#    Copyright (C) European Synchrotron Radiation Facility, Grenoble, France
+#    Copyright (C) 2012-2018 European Synchrotron Radiation Facility, Grenoble, France
 #
 #    Principal author:       Jérôme Kieffer (Jerome.Kieffer@ESRF.eu)
 #
@@ -39,7 +39,7 @@ __author__ = "Jerome Kieffer"
 __contact__ = "Jerome.Kieffer@ESRF.eu"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
-__date__ = "08/09/2017"
+__date__ = "01/02/2018"
 __status__ = "production"
 __docformat__ = 'restructuredtext'
 
@@ -53,15 +53,11 @@ from collections import namedtuple, OrderedDict
 
 from . import detectors
 from . import units
-from .decorators import deprecated
+from .utils.decorators import deprecated
 from .utils import crc32
 from . import utils
-try:
-    from .third_party import six
-except ImportError:
-    import six
 
-logger = logging.getLogger("pyFAI.geometry")
+logger = logging.getLogger(__name__)
 
 try:
     from .ext import _geometry
@@ -228,8 +224,8 @@ class Geometry(object):
         """Calculate the position of a set of points in space in the sample's centers referential.
 
         This is usually used for calculating the pixel position in space.
-        
-        Nota: dim3 is the same as dim0  
+
+        Nota: dim3 is the same as dim0
 
         :param d0: altitude on the point compared to the detector (i.e. z), may be None
         :param d1: position on the detector along the slow dimension (i.e. y)
@@ -303,8 +299,8 @@ class Geometry(object):
 
         if (path == "cython") and (_geometry is not None):
             if param is None:
-                dist, poni1, poni2, rot1, rot2, rot3 = self._dist, self._poni1, \
-                                self._poni2, self._rot1, self._rot2, self._rot3
+                dist, poni1, poni2 = self._dist, self._poni1, self._poni2
+                rot1, rot2, rot3 = self._rot1, self._rot2, self._rot3
             else:
                 dist, poni1, poni2, rot1, rot2, rot3 = param[:6]
             p1, p2, p3 = self._calc_cartesian_positions(d1, d2, poni1, poni2)
@@ -343,8 +339,8 @@ class Geometry(object):
 
         if (_geometry is not None) and (path == "cython"):
             if param is None:
-                dist, poni1, poni2, rot1, rot2, rot3 = self._dist, self._poni1, \
-                                self._poni2, self._rot1, self._rot2, self._rot3
+                dist, poni1, poni2 = self._dist, self._poni1, self._poni2
+                rot1, rot2, rot3 = self._rot1, self._rot2, self._rot3
             else:
                 dist, poni1, poni2, rot1, rot2, rot3 = param[:6]
 
@@ -379,8 +375,8 @@ class Geometry(object):
 
         if (_geometry is not None) and (path == "cython"):
             if param is None:
-                dist, poni1, poni2, rot1, rot2, rot3 = self._dist, self._poni1, \
-                                self._poni2, self._rot1, self._rot2, self._rot3
+                dist, poni1, poni2 = self._dist, self._poni1, self._poni2
+                rot1, rot2, rot3 = self._rot1, self._rot2, self._rot3
             else:
                 dist, poni1, poni2, rot1, rot2, rot3 = param[:6]
 
@@ -508,9 +504,9 @@ class Geometry(object):
     def chi(self, d1, d2, path="cython"):
         """
         Calculate the chi (azimuthal angle) for the centre of a pixel
-        at coordinate d1, d2. 
+        at coordinate d1, d2.
         Conversion to lab coordinate system is performed in calc_pos_zyx.
-        
+
         :param d1: pixel coordinate along the 1st dimention (C convention)
         :type d1: float or array of them
         :param d2: pixel coordinate along the 2nd dimention (C convention)
@@ -618,8 +614,8 @@ class Geometry(object):
         :type shape: 2-tuple of integer
         :param unit: string like "2th_deg" or an instance of pyFAI.units.Unit
         :param use_cython: set to False to use the slower Python path (for tests)
-        :param scale: set to False for returning the internal representation 
-                        (S.I. often) which is faster 
+        :param scale: set to False for returning the internal representation
+                      (S.I. often) which is faster
         :return: 3d array with shape=(\*shape,4,2) the two elements are:
             - dim3[0]: radial angle 2th, q, r...
             - dim3[1]: azimuthal angle chi
@@ -644,7 +640,7 @@ class Geometry(object):
             with self._sem:
                 if self._cached_array.get(key) is None or shape != self._cached_array.get(key).shape[:2]:
                     corners = None
-                    if use_cython:
+                    if (_geometry is not None) and use_cython:
                         if self.detector.IS_CONTIGUOUS:
                             d1 = utils.expand2d(numpy.arange(shape[0] + 1.0), shape[1] + 1.0, False)
                             d2 = utils.expand2d(numpy.arange(shape[1] + 1.0), shape[0] + 1.0, True)
@@ -661,6 +657,8 @@ class Geometry(object):
                                                           space, self._wavelength)
                         except KeyError:
                             logger.warning("No fast path for space: %s", space)
+                        except AttributeError as err:
+                            logger.warning("AttributeError: The binary extension _geomety may be missing: %s", err)
                         else:
                             if self.detector.IS_CONTIGUOUS:
                                 if bilinear:
@@ -712,7 +710,7 @@ class Geometry(object):
 
         :param shape: expected shape
         :type shape: 2-tuple of integer
-        :return: 3d array with shape=(*shape,4,2) the two elements are:
+        :return: 3d array with shape=(\*shape,4,2) the two elements are:
            * dim3[0]: radial angle 2th
            * dim3[1]: azimuthal angle chi
         """
@@ -726,7 +724,7 @@ class Geometry(object):
 
         :param shape: expected shape
         :type shape: 2-tuple of integer
-        :return: 3d array with shape=(*shape,4,2) the two elements are (scattering vector q, azimuthal angle chi)
+        :return: 3d array with shape=(\*shape,4,2) the two elements are (scattering vector q, azimuthal angle chi)
         """
         return self.corner_array(shape, unit=units.Q, use_cython=False, scale=False)
 
@@ -738,7 +736,7 @@ class Geometry(object):
 
         :param shape: expected shape
         :type shape: 2-tuple of integer
-        :return: 3d array with shape=(*shape,4,2) the two elements are (radial distance, azimuthal angle chi)
+        :return: 3d array with shape=(\*shape,4,2) the two elements are (radial distance, azimuthal angle chi)
         """
         return self.corner_array(shape, unit=units.R, use_cython=False, scale=False)
 
@@ -750,7 +748,7 @@ class Geometry(object):
 
         :param shape: expected shape
         :type shape: 2-tuple of integer
-        :return: 3d array with shape=(*shape,4,2) the two elements are (reciprocal spacing squared, azimuthal angle chi)
+        :return: 3d array with shape=(\*shape,4,2) the two elements are (reciprocal spacing squared, azimuthal angle chi)
         """
         return self.corner_array(shape, unit=units.RecD2_NM, scale=False)
 
@@ -762,8 +760,8 @@ class Geometry(object):
         :param shape: expected shape
         :type shape: 2-tuple of integer
         :param unit: string like "2th_deg" or an instance of pyFAI.units.Unit
-        :param scale: set to False for returning the internal representation 
-                (S.I. often) which is faster 
+        :param scale: set to False for returning the internal representation
+                (S.I. often) which is faster
         :return: 3d array with shape=(\*shape,4,2) the two elements are:
             - dim3[0]: radial angle 2th, q, r...
             - dim3[1]: azimuthal angle chi
@@ -804,8 +802,8 @@ class Geometry(object):
         :param shape: expected shape
         :type shape: 2-tuple of integer
         :param unit: string like "2th_deg" or an instance of pyFAI.units.Unit
-        :param scale: set to False for returning the internal representation 
-                (S.I. often) which is faster 
+        :param scale: set to False for returning the internal representation
+                (S.I. often) which is faster
         :return: 3d array with shape=(\*shape,4,2) the two elements are:
 
             - dim3[0]: radial angle 2th, q, r...
@@ -944,8 +942,8 @@ class Geometry(object):
         :type typ: str
         :param unit: can be Q, TTH, R for now
         :type unit: pyFAI.units.Enum
-        :param scale: set to False for returning the internal representation 
-                (S.I. often) which is faster 
+        :param scale: set to False for returning the internal representation
+                (S.I. often) which is faster
         :return: R, Q or 2Theta array depending on unit
         :rtype: ndarray
         """
@@ -1526,24 +1524,24 @@ class Geometry(object):
         Calculate the polarization correction accoding to the
         polarization factor:
 
-        * If the polarization factor is None, 
+        * If the polarization factor is None,
             the correction is not applied (returns 1)
-        * If the polarization factor is 0 (circular polarization), 
+        * If the polarization factor is 0 (circular polarization),
             the correction correspond to (1+(cos2θ)^2)/2
-        * If the polarization factor is 1 (linear horizontal polarization), 
+        * If the polarization factor is 1 (linear horizontal polarization),
             there is no correction in the vertical plane  and a node at 2th=90, chi=0
-        * If the polarization factor is -1 (linear vertical polarization), 
+        * If the polarization factor is -1 (linear vertical polarization),
             there is no correction in the horizontal plane and a node at 2th=90, chi=90
         * If the polarization is elliptical, the polarization factor varies between -1 and +1.
 
-        The axis_offset parameter allows correction for the misalignement of 
+        The axis_offset parameter allows correction for the misalignement of
         the polarization plane (or ellipse main axis) and the the detector's X axis.
 
-        :param factor: (Ih-Iv)/(Ih+Iv): varies between 0 (circular/random polarization) 
+        :param factor: (Ih-Iv)/(Ih+Iv): varies between 0 (circular/random polarization)
                     and 1 (where division by 0 could occure at 2th=90, chi=0)
-        :param axis_offset: Angle between the polarization main axis and 
+        :param axis_offset: Angle between the polarization main axis and
                             detector's X direction (in radians !!!)
-        :return: 2D array with polarization correction array 
+        :return: 2D array with polarization correction array
                         (intensity/polarisation)
 
         """
@@ -1646,7 +1644,7 @@ class Geometry(object):
         """
         Computes a 2D image from a 1D integrated profile
 
-        :param tth: 1D array with radial unit, this array needs to be ordered 
+        :param tth: 1D array with radial unit, this array needs to be ordered
         :param I: scattering intensity, corresponding intensity
         :param shape: shape of the image (if not defined by the detector)
         :param dim1_unit: unit for the "tth" array
@@ -1660,7 +1658,7 @@ class Geometry(object):
 
         """
         dim1_unit = units.to_unit(dim1_unit)
-        tth = tth.copy() / dim1_unit.scale
+        tth = tth / dim1_unit.scale
 
         if shape is None:
             shape = self.detector.max_shape
@@ -1688,6 +1686,73 @@ class Geometry(object):
             calcimage[numpy.where(mask)] = dummy
         return calcimage
 
+    def calcfrom2d(self, I, tth, chi, shape=None, mask=None,
+                   dim1_unit=units.TTH, dim2_unit=units.CHI_DEG,
+                   correctSolidAngle=True, dummy=0.0,
+                   polarization_factor=None, polarization_axis_offset=0,
+                   dark=None, flat=None,
+                   ):
+        """
+        Computes a 2D image from a cake / 2D integrated image
+
+        :param I: scattering intensity, as an image n_tth, n_chi
+        :param tth: 1D array with radial unit, this array needs to be ordered
+        :param chi: 1D array with azimuthal unit, this array needs to be ordered
+        :param shape: shape of the image (if not defined by the detector)
+        :param dim1_unit: unit for the "tth" array
+        :param dim2_unit: unit for the "chi" array
+        :param correctSolidAngle:
+        :param dummy: value for masked pixels
+        :param polarization_factor: set to true to use previously used value
+        :param polarization_axis_offset: axis_offset to be send to the polarization method
+        :param dark: dark current correction
+        :param flat: flatfield corrction
+        :return: 2D image reconstructed
+
+        """
+        dim1_unit = units.to_unit(dim1_unit)
+        dim2_unit = units.to_unit(dim2_unit)
+        tth = numpy.ascontiguousarray(tth, numpy.float64) / dim1_unit.scale
+        chi = numpy.ascontiguousarray(chi, numpy.float64) / dim2_unit.scale
+        if shape is None:
+            shape = self.detector.max_shape
+        try:
+            ttha = self.__getattribute__(dim1_unit.center)(shape)
+
+        except:
+            raise RuntimeError("in pyFAI.Geometry.calcfrom1d: " +
+                               str(dim1_unit) + " not (yet?) Implemented")
+        chia = self.chia
+
+        built_mask = numpy.ones(shape, dtype=numpy.int8)
+        empty_data = numpy.zeros(shape, dtype=numpy.float32)
+
+        from .ext.inpainting import polar_interpolate
+
+        calcimage = polar_interpolate(empty_data,
+                                      mask=built_mask,
+                                      radial=ttha,
+                                      azimuthal=chia,
+                                      polar=I,
+                                      rad_pos=tth,
+                                      azim_pos=chi)
+        if correctSolidAngle:
+            calcimage *= self.solidAngleArray(shape)
+        if polarization_factor is not None:
+            calcimage *= self.polarization(shape, polarization_factor,
+                                           axis_offset=polarization_axis_offset,
+                                           with_checksum=False)
+        if flat is not None:
+            assert flat.shape == tuple(shape)
+            calcimage *= flat
+        if dark is not None:
+            assert dark.shape == tuple(shape)
+            calcimage += dark
+        if mask is not None:
+            assert mask.shape == tuple(shape)
+            calcimage[numpy.where(mask)] = dummy
+        return calcimage
+
     def __copy__(self):
         """:return: a shallow copy of itself.
         """
