@@ -3,7 +3,7 @@
 #    Project: Azimuthal integration
 #             https://github.com/silx-kit/pyFAI
 #
-#    Copyright (C) 2015 European Synchrotron Radiation Facility, Grenoble, France
+#    Copyright (C) 2015-2018 European Synchrotron Radiation Facility, Grenoble, France
 #
 #    Principal author:       Jérôme Kieffer (Jerome.Kieffer@ESRF.eu)
 #
@@ -45,7 +45,7 @@ __author__ = "Jerome Kieffer"
 __contact__ = "Jerome.Kieffer@ESRF.eu"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
-__date__ = "14/09/2017"
+__date__ = "10/01/2018"
 __status__ = "production"
 __docformat__ = 'restructuredtext'
 
@@ -69,7 +69,7 @@ from . import units
 from . import version
 
 
-logger = logging.getLogger("pyFAI.io")
+logger = logging.getLogger(__name__)
 try:
     import h5py
 except ImportError as error:
@@ -234,7 +234,7 @@ class HDF5Writer(Writer):
         if fast_scan_width is not None:
             try:
                 self.fast_scan_width = int(fast_scan_width)
-            except:
+            except ValueError:
                 pass
         self.hdf5 = None
         self.group = None
@@ -497,7 +497,7 @@ class DefaultAiWriter(Writer):
         :type error: numpy.ndarray or None
         :param dim1_unit: the unit of the dim1 array
         :type dim1_unit: pyFAI.units.Unit
-        :param has_mask: a mask was used 
+        :param has_mask: a mask was used
         :param has_dark: a dark-current was applied
         :param has_flat: flat-field was applied
         :param polarization_factor: the polarization factor
@@ -544,7 +544,7 @@ class DefaultAiWriter(Writer):
         :type error: numpy.ndarray or None
         :param dim1_unit: the unit of the dim1 array
         :type dim1_unit: pyFAI.units.Unit
-        :param has_mask: a mask was used 
+        :param has_mask: a mask was used
         :param has_dark: a dark-current was applied
         :param has_flat: flat-field was applied
         :param polarization_factor: the polarization factor
