@@ -3,7 +3,7 @@
 #    Project: Azimuthal integration
 #             https://github.com/silx-kit/pyFAI
 #
-#    Copyright (C) European Synchrotron Radiation Facility, Grenoble, France
+#    Copyright (C) 2012-2018 European Synchrotron Radiation Facility, Grenoble, France
 #
 #    Principal author:       Jérôme Kieffer (Jerome.Kieffer@ESRF.eu)
 #                            D. Karkoulis (dimitris.karkoulis@gmail.com)
@@ -42,7 +42,7 @@ TODO and trick from dimitris still missing:
 """
 __author__ = "Jérôme Kieffer"
 __license__ = "MIT"
-__date__ = "02/02/2017"
+__date__ = "10/01/2018"
 __copyright__ = "2012, ESRF, Grenoble"
 __contact__ = "jerome.kieffer@esrf.fr"
 
@@ -56,7 +56,7 @@ if pyopencl:
     mf = pyopencl.mem_flags
 else:
     raise ImportError("pyopencl is not installed")
-logger = logging.getLogger("pyFAI.ocl_azim_pyocl")
+logger = logging.getLogger(__name__)
 
 
 class Integrator1d(object):
@@ -242,8 +242,8 @@ class Integrator1d(object):
         kernel_file = kernel_file or "ocl_azim_kernel_2.cl"
         kernel_src = concatenate_cl_kernel([kernel_file])
 
-        compile_options = "-D BLOCK_SIZE=%i  -D BINS=%i -D NN=%i" % \
-                            (self.BLOCK_SIZE, self.nBins, self.nData)
+        template_options = "-D BLOCK_SIZE=%i  -D BINS=%i -D NN=%i"
+        compile_options = template_options % (self.BLOCK_SIZE, self.nBins, self.nData)
         if self.useFp64:
             compile_options += " -D ENABLE_FP64"
 
