@@ -4,7 +4,7 @@
 #    Project: Azimuthal integration
 #             https://github.com/silx-kit/pyFAI
 #
-#    Copyright (C) 2015 European Synchrotron Radiation Facility, Grenoble, France
+#    Copyright (C) 2015-2018 European Synchrotron Radiation Facility, Grenoble, France
 #
 #    Principal author:       Jérôme Kieffer (Jerome.Kieffer@ESRF.eu)
 #
@@ -35,16 +35,17 @@ __author__ = "Jérôme Kieffer"
 __contact__ = "Jerome.Kieffer@ESRF.eu"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
-__date__ = "19/07/2017"
+__date__ = "10/01/2018"
 
 import unittest
 import numpy
 import os
+import logging
 import fabio
-from .utilstest import UtilsTest, getLogger
+from .utilstest import UtilsTest
 from .. import average
 
-logger = getLogger(__file__)
+logger = logging.getLogger(__name__)
 
 
 # TODO add tests from
@@ -104,7 +105,7 @@ class TestAverage(unittest.TestCase):
             fformat=None)
 
         self.assertTrue(numpy.allclose(result, expected),
-                     "average with quantiles gives bad results")
+                        "average with quantiles gives bad results")
 
     def test_output_file(self):
         if fabio.hexversion < 262147:
