@@ -4,7 +4,7 @@
 #    Project: Azimuthal integration
 #             https://github.com/silx-kit/pyFAI
 #
-#    Copyright (C) 2015 European Synchrotron Radiation Facility, Grenoble, France
+#    Copyright (C) 2015-2018 European Synchrotron Radiation Facility, Grenoble, France
 #
 #    Principal author:       Jérôme Kieffer (Jerome.Kieffer@ESRF.eu)
 #
@@ -28,17 +28,18 @@
 
 from __future__ import absolute_import, division, print_function
 
-__doc__ = "test suite for blob detection cython accelerated code"
+"""Test suite for blob detection cython accelerated code"""
+
 __author__ = "Jérôme Kieffer"
 __contact__ = "Jerome.Kieffer@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
-__date__ = "19/07/2017"
+__date__ = "10/01/2018"
 
 import unittest
 import numpy
-from .utilstest import getLogger
-logger = getLogger(__file__)
+import logging
+logger = logging.getLogger(__name__)
 from ..detectors import detector_factory
 from ..azimuthalIntegrator import AzimuthalIntegrator
 from ..blob_detection import BlobDetection, local_max
@@ -77,10 +78,10 @@ class TestBlobDetection(unittest.TestCase):
     def test_local_max(self):
         bd = BlobDetection(self.img)
         bd._one_octave(shrink=False, refine=False, n_5=False)
-        self.assertTrue(numpy.alltrue(_blob.local_max(bd.dogs, bd.cur_mask, False) == \
-                                   local_max(bd.dogs, bd.cur_mask, False)), "max test, 3x3x3")
-        self.assertTrue(numpy.alltrue(_blob.local_max(bd.dogs, bd.cur_mask, True) == \
-                                   local_max(bd.dogs, bd.cur_mask, True)), "max test, 3x5x5")
+        self.assertTrue(numpy.alltrue(_blob.local_max(bd.dogs, bd.cur_mask, False) ==
+                                      local_max(bd.dogs, bd.cur_mask, False)), "max test, 3x3x3")
+        self.assertTrue(numpy.alltrue(_blob.local_max(bd.dogs, bd.cur_mask, True) ==
+                                      local_max(bd.dogs, bd.cur_mask, True)), "max test, 3x5x5")
 
 
 def suite():
